:userdoc.
:title.VX-REXX Extras Reference


.* ****************************************************************************
:h1 x=left y=bottom width=100% height=100% id=vrx_functions.VX-REXX Extras - Functions
:p.This section describes the new functions provided by the VX-REXX Extras library.


.* ----------------------------------------------------------------------------
.* VRXLoadFuncs & VRXDropFuncs
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=func_vrxfuncs group=1.Library management
:p.Select an item&colon.
:link reftype=hd refid=vrxfuncs_desc auto.
:p.:link reftype=hd refid=vrxfuncs_desc.Overview:elink.
.br
:link reftype=hd refid=vrxfuncs_args.Arguments:elink.
.br
:link reftype=hd refid=vrxfuncs_returns.Returns:elink.
.br
:link reftype=hd refid=vrxfuncs_examples.Examples:elink.


:h2 x=25% y=bottom width=75% height=100% id=vrxfuncs_desc hide group=2.Overview - VRLoadFuncs &amp. VRXDropFuncs
:p.:hp7.Syntax:ehp7.
:xmp.VRLoadFuncs()

VRXDropFuncs()
:exmp.

:p.:hp7.Description:ehp7.
:p.:hp2.VRXLoadFuncs:ehp2. registers all functions in the VX-REXX Extras library
(other than itself).
:p.:hp2.VRXDropFuncs:ehp2. deregisters all functions in the VX-REXX Extras
library (including itself).


:h2 x=25% y=bottom width=75% height=50% id=vrxfuncs_args hide group=3.Arguments - VRLoadFuncs &amp. VRXDropFuncs
:p.The :hp2.VRLoadFuncs:ehp2. and :hp2.VRXDropFuncs:ehp2. functions take no arguments.

:h2 x=25% y=bottom width=75% height=50% id=vrxfuncs_returns hide group=3.Returns - VRLoadFuncs &amp. VRXDropFuncs
:p.Both :hp2.VRLoadFuncs:ehp2. and :hp2.VRXDropFuncs:ehp2. return a null string
("").

:h2 x=25% y=bottom width=75% height=50% id=vrxfuncs_examples hide group=3.Examples - VRLoadFuncs &amp. VRXDropFuncs
:p.This example loads all functions in the VX-REXX Extras library.
:xmp.
call RxFuncAdd 'VRXLoadFuncs', 'VROBJEX', 'VRXLoadFuncs'
call VRXLoadFuncs
:exmp.
:p.This example unloads all functions in the VX-REXX Extras library.
:xmp.
call VRXDropFuncs
:exmp.


.* ----------------------------------------------------------------------------
.* VRXColourDialog function
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=func_vrxcolordialog.VRXColorDialog
:link reftype=hd refid=func_vrxcolourdialog auto.

:h2 x=left y=bottom width=25% height=100% id=func_vrxcolourdialog group=1.VRXColourDialog
:p.Select an item&colon.
:link reftype=hd refid=vrxcolourdialog_desc auto.
:p.:link reftype=hd refid=vrxcolourdialog_desc.Overview:elink.
.br
:link reftype=hd refid=vrxcolourdialog_args.Arguments:elink.
.br
:link reftype=hd refid=vrxcolourdialog_returns.Returns:elink.
.br
:link reftype=hd refid=vrxcolourdialog_notes.Notes:elink.
.br
:link reftype=hd refid=vrxcolourdialog_examples.Examples:elink.
.br
:link reftype=hd refid=vrxcolourdialog_refs.See also :elink.


:h2 x=25% y=bottom width=75% height=100% id=vrxcolourdialog_desc hide group=2.Overview - VRXColourDialog function
:p.:hp7.Syntax:ehp7.
:xmp.clrValue = VRXColourDialog( [ :hp1.object:ehp1. ], [ :hp1.initialClr:ehp1. ], [ :hp1.title:ehp1. ] )
:exmp.
:hp2.or:ehp2.
:xmp.clrValue = VRXColorDialog( [ :hp1.object:ehp1. ], [ :hp1.initialClr:ehp1. ], [ :hp1.title:ehp1. ] )
:exmp.

:p.:hp7.Description:ehp7.
:p.This function presents a colour selection dialog.  It can be used to allow
a user to select or edit a colour value using the OS/2 Presentation Manager
&osq.colour wheel&csq. and/or RGB value spinbutton controls.
:p.The dialog includes the following buttons&colon.
:dl compact.
:dt.OK
:dd.Closes the dialog and returns the currently-selected colour value.
:dt.Reset
:dd.Reverts the current selections to the :hp1.initialClr:ehp1. value
(without closing the dialog).
:dt.Cancel
:dd.Closes the dialog and returns a null string.
:edl.


:h2 x=25% y=bottom width=75% height=50% id=vrxcolourdialog_args hide group=3.Arguments - VRXColourDialog function
:dl break=all.
:dt.:hp1.object:ehp1.
:dd.The name of the window to which the dialog is to be modal.  This may be the
object's name (e.g. "Window1"), or its VX-REXX handle (as returned by
:link reftype=hd refid='7800' database='A2Z.INF'.VRWindow:elink.).  The
specified object will be disabled while the dialog is open.
:p.If this parameter is omitted, or a null string is specified, the desktop
window will be used.  This will cause the dialog to be non-modal, but the
caller will still wait for the dialog to close before continuing.  (Note that
any events sent to the caller while the dialog is open will accumulate in
the message queue.)

:dt.:hp1.initialClr:ehp1.
:dd.The initial colour selection which the dialog will display.  Must be one
of the following&colon.
:ul compact.
:li.A string of the form "(R,G,B)", where R, G, and B are decimal numbers (0 to
255) representing red, green, and blue colour values, respectively.
:li.A string of the form "#RRGGBB", where RR, GG, and BB are two-digit
hexadecimal numbers (0 to FF) representing red, green, and blue colour values,
respectively.
:eul.
:p.If not specified, the default is "(255,255,255)" (white).

:dt.:hp1.title:ehp1.
:dd.The title to be displayed in the dialog window.  If omitted, the default
title is "".
:edl.

:h2 x=25% y=bottom width=75% height=50% id=vrxcolourdialog_returns hide group=3.Returns - VRXColourDialog function
:p.The return value is a string representing the selected colour value.
:p.If the :hp1.initialClr:ehp1. value was specified using "#RRGGBB" format,
then the return value will use the same format.  Otherwise, the return value is
a string in of form "(R,G,B)".  (Refer to the :hp1.initialClr:ehp1. argument
for a description of these strings.)
:p.If the dialog is closed using the Cancel button, or if an error occurred,
then the return value will be a null string ("").
:p.If the event of an error, the global variable VRXERROR will contain a
non-zero error code.

:h2 x=25% y=bottom width=75% height=50% id=vrxcolourdialog_notes hide group=3.Notes - VRXColourDialog function
:p.In order to accomodate the different spelling conventions within the English
language, this function is available under two names&colon.
:hp2.VRXColorDialog:ehp2. and :hp2.VRXColourDialog:ehp2..  Either may be used,
as the developer prefers.

:h2 x=25% y=bottom width=75% height=50% id=vrxcolourdialog_examples hide group=3.Examples - VRXColourDialog function
:p.This example changes a pushbutton control's background to a new colour
chosen by the user.
:xmp.
defClr = VRGet("PB_1", "BackColor")
if defClr == "<default>" then
    defClr = "(204,204,204)"
clr = VRXColourDialog( VRWindow(), defClr, "Select Colour")
if clr <> "" then
    call VRSet "PB_1", "BackColor", clr
:exmp.

:h2 x=25% y=bottom width=75% height=50% id=vrxcolourdialog_refs hide group=3.See also - VRXColourDialog function
:ul compact.
:li.:link reftype=hd refid='2040' database='A2Z.INF'.BackColor:elink.
:li.:link reftype=hd refid='2340' database='A2Z.INF'.ForeColor:elink.
:eul.


.* ----------------------------------------------------------------------------
.* VRXGetClipboardText function
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=func_vrxgetclipboardtext group=1.VRXGetClipboardText
:p.Select an item&colon.
:link reftype=hd refid=vrxgetclipboardtext_desc auto.
:p.:link reftype=hd refid=vrxgetclipboardtext_desc.Overview:elink.
.br
:link reftype=hd refid=vrxgetclipboardtext_args.Arguments:elink.
.br
:link reftype=hd refid=vrxgetclipboardtext_returns.Returns:elink.
.br
:link reftype=hd refid=vrxgetclipboardtext_notes.Notes:elink.
.br
:link reftype=hd refid=vrxgetclipboardtext_examples.Examples:elink.
.br
:link reftype=hd refid=vrxgetclipboardtext_refs.See also :elink.


:h2 x=25% y=bottom width=75% height=100% id=vrxgetclipboardtext_desc hide group=2.Overview - VRXGetClipboardText function
:p.:hp7.Syntax:ehp7.
:xmp.clipText = VRXGetClipboardText()
:exmp.
:p.:hp7.Description:ehp7.
:p.This function retrieves the current text from the OS/2 clipboard, if any
exists.
:p.Unlike the :link reftype=hd  refid='5950' database='A2Z.INF'.GetClipboard:elink.
method, this function does not require an
:link reftype=hd  refid='1000' database='A2Z.INF'.Application:elink. object,
and can be used by text-mode REXX programs (as long as Presentation Manager is
running).

:h2 x=25% y=bottom width=75% height=50% id=vrxgetclipboardtext_args hide group=3.Arguments - VRXGetClipboardText function
:p.The :hp2.VRXGetClipboardText:ehp2. function has no arguments.

:h2 x=25% y=bottom width=75% height=50% id=vrxgetclipboardtext_returns hide group=3.Returns - VRXGetClipboardText function
:p.The returned value is a string corresponding to the text retrieved from the
clipboard.
:p.If the event of an error, a null string will be returned, and the global
variable VRXERROR will contain a non-zero error code.

:h2 x=25% y=bottom width=75% height=50% id=vrxgetclipboardtext_notes hide group=3.Notes - VRXGetClipboardText function
:p.This function retrieves the current CF_TEXT (plain text) contents of the
clipboard.  Other clipboard formats are ignored.
:p.There is no specific limit on the amount of text which may be retrieved by
this function.  However, various window controls may have their own limits on
the amount of text which may be inserted.

:h2 x=25% y=bottom width=75% height=50% id=vrxgetclipboardtext_examples hide group=3.Examples - VRXGetClipboardText function
:p.This example retrives the current clipboard text.
:xmp.
    text = VRXGetClipboardText()
:exmp.

:h2 x=25% y=bottom width=75% height=50% id=vrxgetclipboardtext_refs hide group=3.See also - VRXGetClipboardText function
:ul compact.
:li.:link reftype=hd refid=func_vrxputclipboardtext.VRXPutClipboardText:elink.
:eul.


.* ----------------------------------------------------------------------------
.* VRXPutClipboardText function
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=func_vrxputclipboardtext group=1.VRXPutClipboardText
:p.Select an item&colon.
:link reftype=hd refid=vrxputclipboardtext_desc auto.
:p.:link reftype=hd refid=vrxputclipboardtext_desc.Overview:elink.
.br
:link reftype=hd refid=vrxputclipboardtext_args.Arguments:elink.
.br
:link reftype=hd refid=vrxputclipboardtext_returns.Returns:elink.
.br
:link reftype=hd refid=vrxputclipboardtext_notes.Notes:elink.
.br
:link reftype=hd refid=vrxputclipboardtext_examples.Examples:elink.
.br
:link reftype=hd refid=vrxputclipboardtext_refs.See also :elink.


:h2 x=25% y=bottom width=75% height=100% id=vrxputclipboardtext_desc hide group=2.Overview - VRXPutClipboardText function
:p.:hp7.Syntax:ehp7.
:xmp.ok = VRXGetClipboardText( [ :hp1.text:ehp1. ], [ :hp1.clearFormats:ehp1. ] )
:exmp.
:p.:hp7.Description:ehp7.
:p.This function writes text to the OS/2 clipboard.
:p.Unlike the :link reftype=hd  refid='5960' database='A2Z.INF'.PutClipboard:elink.
method, this function does not require an
:link reftype=hd  refid='1000' database='A2Z.INF'.Application:elink. object,
and can be used by text-mode REXX programs (as long as Presentation Manager is
running).

:h2 x=25% y=bottom width=75% height=50% id=vrxputclipboardtext_args hide group=3.Arguments - VRXPutClipboardText function
:dl break=all.
:dt.:hp1.text:ehp1.
:dd.The string to be written to the clipboard.  The string's contents will be
saved to the clipboard in CF_TEXT format; any existing clipboard data which is
in CF_TEXT format will be cleared.
:p.If either no value or a null string is specified, all CF_TEXT data currently
in the clipboard will be cleared.
:dt.:hp1.clearFormats:ehp1.
:dd.Determines whether or not the clipboard should be emptied of all formats
(not just CF_TEXT) before writing the new text.
:dl compact break=none.
:dt.1 or Y
:dd.Clear all clipboard formats before writing data; this is the default.
:dt.0 or N
:dd.Leave intact any clipboard data which is not in CF_TEXT format.
:edl.
:edl.

:h2 x=25% y=bottom width=75% height=50% id=vrxputclipboardtext_returns hide group=3.Returns - VRXPutClipboardText function
:p.The return value will be 1 if the text was written to the clipboard
successfully, or 0 if writing to the clipboard failed.
:p.If an error occurred, the global variable VRXERROR will be set to a non-zero
error code.

:h2 x=25% y=bottom width=75% height=50% id=vrxputclipboardtext_notes hide group=3.Notes - VRXPutClipboardText function
:p.It is possible, using this function, to leave non-text clipboard data intact
when copying (unlike the standard VX-REXX
:link reftype=hd  refid='5960' database='A2Z.INF'.PutClipboard:elink.
method).  Doing so is not normally recommended, as it leaves the clipboard in
an unpredictable state which can be confusing for the user.  However, there may
be circumstances where this is desirable.

:h2 x=25% y=bottom width=75% height=50% id=vrxputclipboardtext_examples hide group=3.Examples - VRXPutClipboardText function
:p.The following example copies a string to the clipboard (clearing all other
clipboard data beforehand)&colon.
:xmp.
copytext = "New clipboard text."
call VRXPutClipboardText copytext
:exmp.

:p.The following example simply clears the OS/2 clipboard of all data&colon.
:xmp.
call VRXPutClipboardText ""
:exmp.

:h2 x=25% y=bottom width=75% height=50% id=vrxputclipboardtext_refs hide group=3.See also - VRXPutClipboardText function
:ul compact.
:li.:link reftype=hd refid=func_vrxgetclipboardtext.VRXGetClipboardText:elink.
:eul.


.* ----------------------------------------------------------------------------
.* VRXVersion function
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=func_vrxversion group=1.VRXVersion
:p.Select an item&colon.
:link reftype=hd refid=vrxversion_desc auto.
:p.:link reftype=hd refid=vrxversion_desc.Overview:elink.
.br
:link reftype=hd refid=vrxversion_args.Arguments:elink.
.br
:link reftype=hd refid=vrxversion_returns.Returns:elink.
.br
:link reftype=hd refid=vrxversion_examples.Examples:elink.


:h2 x=25% y=bottom width=75% height=100% id=vrxversion_desc hide group=2.Overview - VRXVersion function
:p.:hp7.Syntax:ehp7.
:xmp.version = VRXVersion()
:exmp.

:p.:hp7.Description:ehp7.
:p.This function returns the current version of the VX-REXX Extras library.

:h2 x=25% y=bottom width=75% height=50% id=vrxversion_args hide group=3.Arguments - VRXVersion function
:p.The :hp2.VRXVersion:ehp2. function has no arguments.

:h2 x=25% y=bottom width=75% height=50% id=vrxversion_returns hide group=3.Returns - VRXVersion function
:p.The return value is a string in the form "X.Y.Z", where X, Y and Z are
decimal numbers representing the major version, minor version, and refresh
level, respectively.
:p.For example, for VX-REXX Extras version 1.0.1, the returned string will be
"1.0.1".

:h2 x=25% y=bottom width=75% height=50% id=vrxversion_examples hide group=3.Examples - VRXVersion function
:p.This example demonstrates how to verify the current VX-REXX Extras version.
:xmp.
version = VRXVersion()
parse var version with _major "." _minor "." _refresh
if _major < 2 then do
    call VRMessage VRWindow(),,
                   "You will need to upgrade to version 2 or later of the " ||,
                   "VX-REXX Extras library before you can use this program." ,,
                   "Wrong Library Version", "E"
    call Quit
end
:exmp.


.* ****************************************************************************
:h1 x=left y=bottom width=100% height=100%.VX-REXX Extras - Objects
:p.This section describes the new objects provided by the VX-REXX Extras
library.


.* ----------------------------------------------------------------------------
.* TabbedDialog object
.* ----------------------------------------------------------------------------

:h2 x=left y=bottom width=25% height=100% id=tdl_top group=1.TabbedDialog object
:p.Select an item&colon.
:link reftype=hd refid=tdl_desc auto.
:p.:link reftype=hd refid=tdl_desc.Description :elink.
.br
:link reftype=hd refid=tdl_props.Properties :elink.
.br
:link reftype=hd refid=tdl_events.Events :elink.
.br
:link reftype=hd refid=tdl_methods.Methods :elink.
.br
:link reftype=hd refid=tdl_notes.Notes :elink.
.br
:link reftype=hd refid=tdl_refs.See also :elink.


:h2 x=25% y=bottom width=75% height=100% id=tdl_desc hide group=2.Description - TabbedDialog object
:artwork name='tabdlg.bmp'.
:p.The TabbedDialog object provides a Warp 4 "new style" notebook control.
:p.This style of notebook is referred to by the Presentation Manager API as a
"tabbed dialog", and this name was chosen for the VX-REXX object in order to
differentiate it from the &osq.regular&csq.
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. control.


:h2 x=25% y=bottom width=75% height=100% id=tdl_props hide group=2.Properties - TabbedDialog object
:ul compact.
:li.:link reftype=hd  refid='2040' database='A2Z.INF'.BackColor :elink.
:li.:link reftype=hd  refid='2200' database='A2Z.INF'.ClassName :elink.
:li.:link reftype=hd  refid='2280' database='A2Z.INF'.Enabled :elink.
:li.:link reftype=hd  refid='2300' database='A2Z.INF'.FirstChild :elink.
:li.:link reftype=hd  refid='2320' database='A2Z.INF'.Font :elink.
:li.:link reftype=hd  refid='2340' database='A2Z.INF'.ForeColor :elink.
:li.:link reftype=hd  refid='2360' database='A2Z.INF'.Height :elink.
:li.:link reftype=hd  refid='2400' database='A2Z.INF'.HelpTag :elink.
:li.:link reftype=hd  refid='2420' database='A2Z.INF'.HelpText :elink.
:li.:link reftype=hd  refid='2460' database='A2Z.INF'.HintText :elink.
:li.:link reftype=hd  refid='3420' database='A2Z.INF'.HWnd :elink.
:li.:link reftype=hd  refid='3560' database='A2Z.INF'.InitialPageList :elink.
:li.:link reftype=hd  refid='3780' database='A2Z.INF'.KeyString :elink.
:li.:link reftype=hd  refid='2640' database='A2Z.INF'.Left :elink.
:li.:link reftype=hd  refid='2760' database='A2Z.INF'.Name :elink.
:li.:link reftype=hd  refid='3520' database='A2Z.INF'.PageCount :elink.
:li.:link reftype=hd  refid='3960' database='A2Z.INF'.Painting :elink.
:li.:link reftype=hd  refid='2780' database='A2Z.INF'.Parent :elink.
:li.:link reftype=hd  refid='8640' database='A2Z.INF'.PreloadPages :elink.
:li.:link reftype=hd  refid='2880' database='A2Z.INF'.Selected :elink.
:li.:link reftype=hd  refid='2980' database='A2Z.INF'.Self :elink.
:li.:link reftype=hd  refid='3060' database='A2Z.INF'.Sibling :elink.
:li.:link reftype=hd  refid='3080' database='A2Z.INF'.SiblingOrder :elink.
:li.:link reftype=hd  refid='prop_tabdirection'.TabDirection :elink.
:li.:link reftype=hd  refid='3180' database='A2Z.INF'.TabIndex :elink.
:li.:link reftype=hd  refid='prop_tabposition'.TabPosition :elink.
:li.:link reftype=hd  refid='3200' database='A2Z.INF'.TabStop :elink.
:li.:link reftype=hd  refid='3240' database='A2Z.INF'.Top :elink.
:li.:link reftype=hd  refid='3260' database='A2Z.INF'.UserData :elink.
:li.:link reftype=hd  refid='3320' database='A2Z.INF'.Visible :elink.
:li.:link reftype=hd  refid='3340' database='A2Z.INF'.Width :elink.
:eul.


:h2 x=25% y=bottom width=75% height=100% id=tdl_events hide group=2.Events - TabbedDialog object
:ul compact.
:li.:link reftype=hd  refid='4020' database='A2Z.INF'.Click :elink.
:li.:link reftype=hd  refid='4320' database='A2Z.INF'.ContextMenu :elink.
:li.:link reftype=hd  refid='8105' database='A2Z.INF'.DragDiscard :elink.
:li.:link reftype=hd  refid='8103' database='A2Z.INF'.DragDrop :elink.
:li.:link reftype=hd  refid='8104' database='A2Z.INF'.DragPrint :elink.
:li.:link reftype=hd  refid='8796' database='A2Z.INF'.DragStart :elink.
:li.:link reftype=hd  refid='4140' database='A2Z.INF'.GotFocus :elink.
:li.:link reftype=hd  refid='4400' database='A2Z.INF'.KeyPress :elink.
:li.:link reftype=hd  refid='4160' database='A2Z.INF'.LostFocus :elink.
:li.:link reftype=hd  refid='4240' database='A2Z.INF'.NewPageSize :elink.
:li.:link reftype=hd  refid='4220' database='A2Z.INF'.PageDeleted :elink.
:li.:link reftype=hd  refid='8660' database='A2Z.INF'.PageLoad :elink.
:li.:link reftype=hd  refid='4200' database='A2Z.INF'.PageSelected :elink.
:eul.


:h2 x=25% y=bottom width=75% height=100% id=tdl_methods hide group=2.Methods - TabbedDialog object
:ul compact.
:li.:link reftype=hd  refid='5580' database='A2Z.INF'.DeletePage :elink.
:li.:link reftype=hd  refid='8665' database='A2Z.INF'.GetPageNumber :elink.
:li.:link reftype=hd  refid='8500' database='A2Z.INF'.GetPageWindow :elink.
:li.:link reftype=hd  refid='8580' database='A2Z.INF'.GetStatusText :elink.
:li.:link reftype=hd  refid='8540' database='A2Z.INF'.GetTabText :elink.
:li.:link reftype=hd  refid='8620' database='A2Z.INF'.InsertBlankPage :elink.
:li.:link reftype=hd  refid='5560' database='A2Z.INF'.InsertPage :elink.
:li.:link reftype=hd  refid='5320' database='A2Z.INF'.InvokeHelp :elink.
:li.:link reftype=hd  refid='5970' database='A2Z.INF'.ListChildren :elink.
:li.:link reftype=hd  refid='5340' database='A2Z.INF'.ListMethods :elink.
:li.:link reftype=hd  refid='5360' database='A2Z.INF'.ListProperties :elink.
:li.:link reftype=hd  refid='8520' database='A2Z.INF'.SetPageWindow :elink.
:li.:link reftype=hd  refid='8600' database='A2Z.INF'.SetStatusText :elink.
:li.:link reftype=hd  refid='8560' database='A2Z.INF'.SetTabText :elink.
:eul.


:h2 x=25% y=bottom width=75% height=100% id=tdl_notes hide group=2.Notes - TabbedDialog object
:p.The TabbedDialog object is a subclass of the standard
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. object, and
is almost completely compatible.
:p.There is one significant difference, however, in how you must handle page
windows.  Normally, when you create a secondary window, VX-REXX automatically
adds the following code to its :hp3.WindowName_:ehp3.:hp2.Init:ehp2.
method&colon.
:xmp.
    if( \VRIsChildOf( window, "Notebook" ) ) then do
        call VRMethod window, "CenterWindow"
        call VRSet window, "Visible", 1
        call VRMethod window, "Activate"
    end
:exmp.
:p.For every page window which is added to the TabbedDialog notebook, you
:hp2.must:ehp2. either remove the above code entirely, or else change the
"Notebook" string in the first line to "TabbedDialog".  Failure to do so will
cause your pages to render improperly when the dialog is first populated.

:p.
:p.Programatically speaking, the only other differences from the standard
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. object are as
follows&colon.
:ul.
:li.The TabbedDialog object does :hp2.not:ehp2. support the following
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. properties&colon.
:ul compact.
:li.:link reftype=hd refid='3600' database='A2Z.INF'.BackPages:elink.
:li.:link reftype=hd  refid='3580' database='A2Z.INF'.Binding:elink.
:li.:link reftype=hd refid='3540' database='A2Z.INF'.MajorTabPos:elink.
:li.:link reftype=hd  refid='3480' database='A2Z.INF'.StatusTextAlignment:elink.
:li.:link reftype=hd  refid='3460' database='A2Z.INF'.TabShape:elink.
:li.:link reftype=hd  refid='3440' database='A2Z.INF'.TabTextAlignment:elink.
:eul.
:li.The TabbedDialog object supports the following properties which are not
supported by the standard
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. object&colon.
:ul compact.
:li.:link reftype=hd  refid='prop_tabdirection'.TabDirection :elink.
:li.:link reftype=hd  refid='prop_tabposition'.TabPosition :elink.
:eul.
:eul.
:p.In all other respects, using the TabbedDialog object is exactly the same as
using the :link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink.
object.
:p.Refer to the :link reftype=hd  refid='UNOTEBK' database='PROGGUID.INF'.Notebooks:elink.
section in the :hp1.VX-REXX Programmer's Guide:ehp1. for details on how to use
notebook controls under VX-REXX.

:h2 x=25% y=bottom width=75% height=100% id=tdl_refs hide group=2.See also - TabbedDialog object
:ul compact.
:li.:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink.
:li.:link reftype=hd refid='1360' database='A2Z.INF'.Window:elink.
:eul.


.* ****************************************************************************
:h1 x=left y=bottom width=100% height=100% id=vrx_properties.VX-REXX Extras - Properties
:p.This section describes new properties used by objects in the VX-REXX Extras
library.


.* ----------------------------------------------------------------------------
:h2 x=left y=bottom id=prop_tabdirection.TabDirection property
:p.The TabDirection property indicates in which direction the tabs on a
:link reftype=hd refid=tdl_top.TabbedDialog:elink. notebook will be aligned
&amp. ordered.
:p.This property may only be set at design time.
:p.There are two possible values&colon.
:dl break=fit tsize=20.
:dt.LeftToRight
:dd.The tabs will be aligned to the left side of the notebook, and ordered from
left to right.  This is the default.
:dt.RightToLeft
:dd.The tabs will be aligned to the right side of the notebook, and ordered from
right to left.
:edl.

:p.
:p.:hp7.Applies to:ehp7.
:p.:link reftype=hd refid=tdl_top.TabbedDialog:elink.

:p.
:p.:hp7.Notes:ehp7.
:p.None.

:p.
:p.:hp7.See also:ehp7.
:p.:link reftype=hd refid=prop_tabposition.TabPosition:elink.


.* ----------------------------------------------------------------------------
:h2 x=left y=bottom width=100% height=100% id=prop_tabposition.TabPosition property
:p.The TabPosition property indicates the location of the tabs on a
:link reftype=hd refid=tdl_top.TabbedDialog:elink. notebook.
:p.This property may only be set at design time.
:p.There are two possible values&colon.
:dl break=fit tsize=20.
:dt.Bottom
:dd.The tabs will appear on the bottom edge of the notebook.
:dt.Top
:dd.The tabs will appear on the top edge of the notebook.  This is the default.
:edl.

:p.
:p.:hp7.Applies to:ehp7.
:p.:link reftype=hd refid=tdl_top.TabbedDialog:elink.

:p.
:p.:hp7.Notes:ehp7.
:p.The TabPosition property of the TabbedDialog control corresponds in both
behaviour and internal implementation to the
:link reftype=hd refid='3540' database='A2Z.INF'.MajorTabPos:elink. property
of the standard
:link reftype=hd refid='1270' database='A2Z.INF'.Notebook:elink. control.  Unlike
the :link reftype=hd refid='3540' database='A2Z.INF'.MajorTabPos:elink. property,
however, TabPosition only supports the values :hp2.Top:ehp2. and
:hp2.Bottom:ehp2., as these are the only styles allowed by the Presentation
Manager tabbed-dialog notebook.

:p.
:p.:hp7.See also:ehp7.
:p.:link reftype=hd refid=prop_tabdirection.TabDirection:elink.

:euserdoc.

